@@ -10,7 +10,9 @@ import grpc
 from qwilprobe.generated.qwilprobe_pb2 import (
     ProbeDataColumn,
     ProbeDataModel,
+    ProbeDatapoint,
     ProbeDataResponse,
+    ProbeDataType,
     ProbeInfoResponse,
     ProbeIsReadyResponse,
     ProbeTerminateResponse,
@@ -169,6 +171,19 @@ def start(address, port):
 
 
 def stop():
+    # Reset the module state
+    global _get_probe_info_handler
+    global _get_probe_is_ready_handler
+    global _get_probe_data_handler
+    global _terminate_handler
+    global _probe_info
+    _get_probe_info_handler = _default_probe_info_handler
+    _get_probe_is_ready_handler = _default_probe_is_ready_handler
+    _get_probe_data_handler = _default_probe_data_handler
+    _terminate_handler = _default_terminate_handler
+    _probe_info = None
+
+
     _terminate_event.set()
 
 
