@@ -10,6 +10,7 @@ from qwilprobe.service.api import (
     RPC_GET_PROBE_IS_READY,
     RPC_TERMINATE,
     qwilprobe_register_handler,
+    qwilprobe_stop,
 )
 
 rpc_param_list = [RPC_GET_PROBE_INFO,
@@ -18,6 +19,10 @@ rpc_param_list = [RPC_GET_PROBE_INFO,
                   RPC_TERMINATE]
 
 
+def teardown_function():
+    qwilprobe_stop()  # Make sure module is reset between tests
+
+
 def dummy_handler():
     """Dummy handler that does nothing."""
     pass
