@@ -15,6 +15,7 @@ from qwilprobe.service.api import (
     KEY_DESCR,
     KEY_UID,
     qwilprobe_set_probe_info,
+    qwilprobe_stop,
 )
 
 good_column_info = [
@@ -35,6 +36,10 @@ good_column_info = [
                    ]
 
 
+def teardown_function():
+    qwilprobe_stop()  # Make sure module is reset between tests
+
+
 def test_set_probe_info_basic():
     """Test setting minimal probe info."""
     qwilprobe_set_probe_info("dummy_uid", good_column_info)
